<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:plm="http://www.plmxml.org/Schemas/PLMXMLSchema"
	xmlns:cim="http://www.coolemall.eu/DEBBComponent">

	<!-- Specification of the output document -->
	<xsl:output method="xml" version="1.0" encoding="UTF-8"
		indent="yes" include-content-type="no" />

	<xsl:template match="/">
		<xsl:apply-templates select="//*[ComponentId]" />
	</xsl:template>

	<xsl:template match="//*[ComponentId]">
		<xsl:element name="computingResource">
			<xsl:attribute name="class">
				<xsl:value-of select="name(.)" />
			</xsl:attribute>
<!--			<xsl:call-template name="BasicDEBBPhysicalElementData" />-->
			<xsl:if test="Baseboard">
				<xsl:apply-templates select="Baseboard" />
			</xsl:if>
			<xsl:if test="Processor">
				<xsl:apply-templates select="Processor" />
			</xsl:if>
			<xsl:if test="Memory">
				<xsl:apply-templates select="Memory" />
			</xsl:if>
			<xsl:if test="Storage">
				<xsl:apply-templates select="Storage" />
			</xsl:if>
			<xsl:if test="CoolingDevice">
				<xsl:apply-templates select="CoolingDevice" />
			</xsl:if>
		</xsl:element>
	</xsl:template>

	<xsl:template match="Baseboard">
		<xsl:element name="parameter">
			<xsl:attribute name="name">Baseboard</xsl:attribute>
			<xsl:call-template name="BasicDEBBPhysicalElementData" />
		</xsl:element>
	</xsl:template>

	<xsl:template match="Processor">
		<xsl:element name="computingResource">
			<xsl:attribute name="class">Processor</xsl:attribute>
			<xsl:call-template name="BasicDEBBPhysicalElementData" />
			<xsl:element name="parameter">
				<xsl:attribute name="name">MaxClockSpeed</xsl:attribute>
				<xsl:element name="value">
					<xsl:value-of select="MaxClockSpeed" />
				</xsl:element>
			</xsl:element>
			<xsl:element name="profile">
				<xsl:comment>
					Power profile and/or air throughput
				</xsl:comment>
				<xsl:if test="PState | CState">
					<!-- If PState or CState elements present add powerProfile element -->
					<xsl:element name="powerProfile">
						<xsl:for-each select="PState">
							<xsl:element name="pstate">

							</xsl:element>
						</xsl:for-each>
					</xsl:element>
				</xsl:if>
			</xsl:element>
			 

		</xsl:element>
	</xsl:template>

	<xsl:template match="Memory">
		<xsl:element name="resourceUnit">
			<xsl:attribute name="class">Memory</xsl:attribute>
			<xsl:call-template name="BasicDEBBPhysicalElementData" />
			<xsl:element name="amount">
				<xsl:value-of select="Capacity" />
			</xsl:element>
		</xsl:element>
	</xsl:template>

	<xsl:template match="Storage">
		<xsl:element name="resourceUnit">
			<xsl:attribute name="class">Storage</xsl:attribute>
			<xsl:call-template name="BasicDEBBPhysicalElementData" />
		</xsl:element>
	</xsl:template>

	<xsl:template match="CoolingDevice">
		<xsl:element name="parameter">
			<xsl:attribute name="name">CoolingDevice</xsl:attribute>
			<xsl:call-template name="BasicDEBBPhysicalElementData" />
		</xsl:element>
	</xsl:template>

	<!-- Template for transforming basic parameters of all devices of any type -->
	<xsl:template name="BasicDEBBPhysicalElementData">
		<xsl:if test="Manufacturer">
			<xsl:element name="parameter">
				<xsl:attribute name="name">Manufacturer</xsl:attribute>
				<xsl:element name="value">
					<xsl:value-of select="Manufacturer" />
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<xsl:if test="Product">
			<xsl:element name="parameter">
				<xsl:attribute name="name">Product</xsl:attribute>
				<xsl:element name="value">
					<xsl:value-of select="Product" />
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<xsl:if test="MaxPower">
			<xsl:element name="parameter">
				<xsl:attribute name="name">MaxPower</xsl:attribute>
				<xsl:element name="value">
					<xsl:value-of select="MaxPower" />
				</xsl:element>
			</xsl:element>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>